.. _xrst_contents-name:

!!!!!!!!
contents
!!!!!!!!

.. _xrst_contents-title:

Table of Contents
*****************
| :ref:`1<example-title>` Examples
|   :ref:`1.1<get_started-title>` Title: Getting Started
|   :ref:`1.2<literal_example-title>` Literal Command Example
|   :ref:`1.3<dir_example-title>` Dir Command Example
|   :ref:`1.4<toc_list_example-title>` toc_list Example Parent Page
|     :ref:`1.4.1<child_example_one-title>` First Child Example Page
|     :ref:`1.4.2<child_example_two-title>` Second Child Example Page
|     :ref:`1.4.3<child_example_three-title>` Third Child Example Page
|   :ref:`1.5<spell_example-title>` Spell Command Example
|   :ref:`1.6<suspend_example-title>` Suspend Command Example
|   :ref:`1.7<code_example-title>` Code Command Example
|   :ref:`1.8<comment_example-title>` Comment Command Example
|   :ref:`1.9<comment_ch_example-title>` Comment Character Command Example
|   :ref:`1.10<heading_example-title>` Heading and Link Example
|   :ref:`1.11<ref_example-title>` Sphinx ref Role Example
|   :ref:`1.12<indent_example-title>` Indent Example
|   :ref:`1.13<docstring_example-title>` Docstring Example
|   :ref:`1.14<configure_example-title>` Example Using TOML Configure File
|   :ref:`1.15<class_example-title>` Example Documenting a Class
|     :ref:`1.15.1<example_ad_double-title>` An Example Using the ad_double Class
|     :ref:`1.15.2<test_ad_double-title>` Run ad_double Example and Check its Result
|   :ref:`1.16<.readthedocs.yaml-title>` Example Read the Docs Configuration
|   :ref:`1.17<template_example-title>` Template Command Example
|     :ref:`1.17.1<example_expansion_one-title>` First Expansion
|     :ref:`1.17.2<example_expansion_two-title>` Second Expansion
|   :ref:`1.18<testExample-title>` Test Special Conditions
| :ref:`2<purpose-title>` Purpose of this Sphinx Wrapper
| :ref:`3<user-guide-title>` Extract Sphinx RST Files
|   :ref:`3.1<config_file-title>` The xrst.toml Configuration File
|   :ref:`3.2<run_xrst-title>` Extract RST Files And Run Sphinx
|   :ref:`3.3<commands-title>` Commands
|     :ref:`3.3.1<begin_cmd-title>` Begin and End Commands
|     :ref:`3.3.2<toc_cmd-title>` Table of Children Commands
|     :ref:`3.3.3<spell_cmd-title>` Spell Command
|     :ref:`3.3.4<suspend_cmd-title>` Suspend and Resume Commands
|     :ref:`3.3.5<indent_cmd-title>` Indent Command
|     :ref:`3.3.6<code_cmd-title>` Code Command
|     :ref:`3.3.7<literal_cmd-title>` Literal Command
|     :ref:`3.3.8<dir_cmd-title>` Converting Sphinx Command File Names
|     :ref:`3.3.9<comment_cmd-title>` Comment Command
|     :ref:`3.3.10<comment_ch_cmd-title>` Comment Character Command
|     :ref:`3.3.11<ref_cmd-title>` Allow Multiple Lines in Sphinx ref Role
|     :ref:`3.3.12<template_cmd-title>` Template Command
|   :ref:`3.4<automatic-title>` Automatic Processing
|     :ref:`3.4.1<heading_links-title>` Heading Cross Reference Links
|     :ref:`3.4.2<auto_file-title>` Automatically Generated Files
|   :ref:`3.5<wish_list-title>` Wish List
| :ref:`4<release_notes-title>` xrst Release Notes By Year
|   :ref:`4.1<2024-title>` xrst Release Notes for 2024
|   :ref:`4.2<2023-title>` xrst Release Notes for 2023
|   :ref:`4.3<2022-title>` xrst Release Notes for 2022
|   :ref:`4.4<2021-title>` xrst Release Notes for 2021
| :ref:`5<module-title>` The xrst Module
|   :ref:`5.1<add_before_title-title>` If PDF, Add Page Number and Name to Title
|   :ref:`5.2<add_line_numbers-title>` Add Line Numbers to File Data
|   :ref:`5.3<auto_file_dev-title>` Create the automatically generated files
|   :ref:`5.4<auto_indent-title>` Automatic Indentation
|   :ref:`5.5<check_input_files-title>` Check That Expected xrst Input Files Are Included
|   :ref:`5.6<check_page_name-title>` Check the rules for a page name
|   :ref:`5.7<code_cmd_dev-title>` Process the xrst code commands for a page
|   :ref:`5.8<comment_cmd_dev-title>` Remove all comment commands
|   :ref:`5.9<dir_cmd_dev-title>` Convert File Names to be Relative to the RST Directory
|   :ref:`5.10<file_line-title>` Determine Input File and Line
|   :ref:`5.11<get_conf_dict-title>` Get Configuration Dictionary
|   :ref:`5.12<get_file_info-title>` Get information for all pages in a file
|   :ref:`5.13<get_spell_checker-title>` Get A Spell Checker Object
|   :ref:`5.14<indent_cmd_dev-title>` Process indent commands in a page
|   :ref:`5.15<literal_cmd_dev-title>` Process the literal commands in a page
|   :ref:`5.16<newline_indices-title>` Find index of all the newlines in a string
|   :ref:`5.17<next_heading-title>` Return location of the next heading in a page
|   :ref:`5.18<xrst.pattern-title>` The xrst.pattern Dictionary
|   :ref:`5.19<process_children-title>` Add child information to a page
|   :ref:`5.20<process_headings-title>` Add labels and index entries for headings
|   :ref:`5.21<ref_cmd_dev-title>` Remove Leading and Trailing White Space From ref Role Targets
|   :ref:`5.22<remove_line_numbers-title>` Remove the number numbers
|   :ref:`5.23<rename_group-title>` Rename a Subset of a Group
|   :ref:`5.24<replace_spell-title>` Replace spelling commands
|   :ref:`5.25<spell_cmd_dev-title>` Process the spell command for a page
|   :ref:`5.26<sphinx_label-title>` Get Labels Declared Using Sphinx Commands
|   :ref:`5.27<start_end_file-title>` Convert literal command start, end from text to line numbers
|   :ref:`5.28<suspend_cmd_dev-title>` Remove text specified by suspend / resume pairs
|   :ref:`5.29<system_exit-title>` Form error message and exit
|   :ref:`5.30<table_of_contents-title>` Create the table of contents and Modify Titles
|   :ref:`5.31<template_cmd_dev-title>` Expand the template commands in a page
|   :ref:`5.32<temporary_file-title>` Write the temporary RST file for a page
|   :ref:`5.33<toc_cmd_dev-title>` Get file and page names for children of this page
